<?php
if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

/**
 * Class WAEF_Admin.
 *
 * WAEF_Admin class handles stuff for admin.
 *
 * @class       WAEF_Admin
 * @author     	multisquares
 * @package		WooCommerce Advanced Shipping
 * @version		1.0.1
 */
class WAEF_Admin {

        /**
	 * Form option fields.
	 * @var array
	 */
	public $form_fields = array();
        
	/**
	 * Constructor.
	 *
	 * @since 1.0.5
	 */
	public function __construct() {
                $this->id                 = 'advanced_extra_fees';
		// Initialize components
		add_action( 'admin_init', array( $this, 'init' ) );
	}


	/**
	 * Initialize class components.
	 *
	 * @since 1.1.8
	 */
	public function init() {
           
		global $pagenow;
                if(isset($_GET['page']) && !empty($_GET['page']) && $_GET['page'] == 'waef'){
                    
                    do_action( 'Woocommerce_Advanced_Extra_Fees_method_init' );
                   
                    $this->init_form_fields();
                }                
                
		// Add to WC Screen IDs to load scripts.
		add_filter( 'woocommerce_screen_ids', array( $this, 'add_waef_screen_ids' ) );
                
		// Enqueue scripts
		add_action( 'admin_enqueue_scripts', array( $this, 'admin_enqueue_scripts' ) );
                
              
                // Keep WC menu open while in WAEF edit screen
		add_action( 'admin_head', array( $this, 'menu_highlight' ) );

		if ( 'plugins.php' == $pagenow ) :
			// Plugins page
			add_filter( 'plugin_action_links_' . plugin_basename( WooCommerce_Advanced_Extra_Fees()->file ), array( $this, 'add_plugin_action_links' ), 10, 2 );
		endif;
                
                

	}
        
	/**
	 * Init fields.
	 *
	 * Add fields to the WAEF shipping settings page.
	 *
	 * @since 1.0.0
	 */
	public function init_form_fields() {

		$this->form_fields = array(
			'enabled' => array(
				'title'   => __( 'Enable/Disable', 'woocommerce' ),
				'type'    => 'checkbox',
				'label'   => __( 'Enable Advanced Shipping', 'woocommerce-advanced-extra-fees' ),
				'default' => 'yes'
			),
			'hide_other_shipping_when_available' => array(
				'title'   => __( 'Hide other shipping', 'woocommerce-advanced-extra-fees' ),
				'type'    => 'checkbox',
				'label'   => __( 'Hide other fees when free shipping is available', 'woocommerce-advanced-extra-fees' ),
				'default' => 'no'
			),
			'waef_shipping_rates_table'           => array(
				'type' => 'waef_shipping_rates_table',
			),
		);

	}

	/**
	 * Screen IDs.
	 *
	 * Add 'waef' to the screen IDs so the WooCommerce scripts are loaded.
	 *
	 * @since 1.0.5
	 *
	 * @param  array $screen_ids List of existing screen IDs.
	 * @return array             List of modified screen IDs.
	 */
	public function add_waef_screen_ids( $screen_ids ) {

		$screen_ids[] = 'waef';

		return $screen_ids;

	}

	/**
	 * Enqueue scripts.
	 *
	 * Enqueue style and java scripts.
	 *
	 * @since 1.0.5
	 */
	public function admin_enqueue_scripts() {

		// Only load scripts on relvant pages
		if (
			( isset( $_REQUEST['post'] ) && 'waef' == get_post_type( $_REQUEST['post'] ) ) ||
			( isset( $_REQUEST['post_type'] ) && 'waef' == $_REQUEST['post_type'] ) ||
			( isset( $_REQUEST['section'] ) && 'waef_advanced_extra_fees_method' == $_REQUEST['section'] || isset($_GET['page']) == 'waef' )
		) :

			// Style script
			wp_enqueue_style( 'woocommerce-advanced-extra-fees-css', plugins_url( 'assets/admin/css/woocommerce-advanced-extra-fees.css', WooCommerce_Advanced_Extra_Fees()->file ), array(), WooCommerce_Advanced_Extra_Fees()->version );

			// Javascript
			wp_enqueue_script( 'woocommerce-advanced-extra-fees-js', plugins_url( 'assets/admin/js/woocommerce-advanced-extra-fees.js', WooCommerce_Advanced_Extra_Fees()->file ), array( 'jquery', 'jquery-ui-sortable', 'jquery-blockui' ), WooCommerce_Advanced_Extra_Fees()->version, true );

			wp_localize_script( 'woocommerce-advanced-extra-fees-js', 'waef', array(
				'nonce' => wp_create_nonce( 'waef-ajax-nonce' ),
			) );

		endif;

	}


	/**
	 * Keep menu open.
	 *
	 * Highlights the correct top level admin menu item for post type add screens.
	 *
	 * @since 1.0.5
	 */
	public function menu_highlight() {
                
		global $parent_file, $post_type; //$parent_file, $submenu_file, $post_type

		if ( 'waef' == $post_type ) :
			$parent_file  = 'waef';
//			$submenu_file = 'wc-settings';
		endif;

	}


	/**
	 * Plugin action links.
	 *
	 * Add links to the plugins.php page below the plugin name
	 * and besides the 'activate', 'edit', 'delete' action links.
	 *
	 * @since 1.1.8
	 *
	 * @param  array  $links List of existing links.
	 * @param  string $file  Name of the current plugin being looped.
	 * @return array         List of modified links.
	 */
	public function add_plugin_action_links( $links, $file ) {

		if ( $file == plugin_basename( WooCommerce_Advanced_Extra_Fees()->file ) ) :
			$links = array_merge( array(
				'<a href="' . esc_url( admin_url( '/admin.php?page=wc-settings&tab=shipping&section=waef_advanced_extra_fees_method' ) ) . '">' . __( 'Settings', 'woocommerce-advanced-extra-fees' ) . '</a>'
			), $links );
		endif;

		return $links;

	}
        


}
